@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2019, Intel Corporation */
+/* Copyright 2019-2021, Intel Corporation */
 
 /*
  * pmemkv_open.cpp -- example usage of pmemkv with already existing pools.
@@ -10,14 +10,21 @@
 #include <iostream>
 #include <libpmemkv.hpp>
 
+#define ASSERT(expr)                                                                     \
+	do {                                                                             \
+		if (!(expr))                                                             \
+			std::cout << pmemkv_errormsg() << std::endl;                     \
+		assert(expr);                                                            \
+	} while (0)
 #define LOG(msg) std::cout << msg << std::endl
 
 using namespace pmem::kv;
 
-/**
- * This example expects a path to already created pool.
+//! [open]
+/*
+ * This example expects a path to already created database pool.
  *
- * To create a pool use one of the following commands.
+ * If you want to create pool, use one of the following commands.
  *
  * For regular pools use:
  * pmempool create -l -s 1G "pmemkv" obj path_to_a_pool
@@ -36,31 +43,33 @@ int main(int argc, char *argv[])
 	LOG("Creating config");
 	config cfg;
 
-	status s = cfg.put_string("path", argv[1]);
-	assert(s == status::OK);
+	status s = cfg.put_path(argv[1]);
+	ASSERT(s == status::OK);
 
 	LOG("Opening pmemkv database with 'cmap' engine");
 	db *kv = new db();
-	assert(kv != nullptr);
+	ASSERT(kv != nullptr);
 	s = kv->open("cmap", std::move(cfg));
-	assert(s == status::OK);
+	ASSERT(s == status::OK);
 
 	LOG("Putting new key");
 	s = kv->put("key1", "value1");
-	assert(s == status::OK);
+	ASSERT(s == status::OK);
 
 	size_t cnt;
 	s = kv->count_all(cnt);
-	assert(s == status::OK && cnt == 1);
+	ASSERT(s == status::OK && cnt == 1);
 
 	LOG("Reading key back");
 	std::string value;
 	s = kv->get("key1", &value);
-	assert(s == status::OK && value == "value1");
+	ASSERT(s == status::OK && value == "value1");
 
 	LOG("Iterating existing keys");
-	kv->put("key2", "value2");
-	kv->put("key3", "value3");
+	s = kv->put("key2", "value2");
+	ASSERT(s == status::OK);
+	s = kv->put("key3", "value3");
+	ASSERT(s == status::OK);
 	kv->get_all([](string_view k, string_view v) {
 		LOG("  visited: " << k.data());
 		return 0;
@@ -68,12 +77,13 @@ int main(int argc, char *argv[])
 
 	LOG("Removing existing key");
 	s = kv->remove("key1");
-	assert(s == status::OK);
+	ASSERT(s == status::OK);
 	s = kv->exists("key1");
-	assert(s == status::NOT_FOUND);
+	ASSERT(s == status::NOT_FOUND);
 
 	LOG("Closing database");
 	delete kv;
 
 	return 0;
 }
+//! [open]
