@@ -4,6 +4,8 @@
 #ifndef LIBPMEMKV_H
 #define LIBPMEMKV_H
 
+#include <libpmemobj/pool_base.h>
+#include <stdbool.h>
 #include <stddef.h>
 #include <stdint.h>
 
@@ -28,6 +30,12 @@ extern "C" {
 typedef struct pmemkv_db pmemkv_db;
 typedef struct pmemkv_config pmemkv_config;
 typedef struct pmemkv_comparator pmemkv_comparator;
+typedef struct pmemkv_tx pmemkv_tx;
+
+typedef struct pmemkv_iterator pmemkv_iterator;
+typedef struct {
+	pmemkv_iterator *iter;
+} pmemkv_write_iterator;
 
 typedef int pmemkv_get_kv_callback(const char *key, size_t keybytes, const char *value,
 				   size_t valuebytes, void *arg);
@@ -36,6 +44,10 @@ typedef void pmemkv_get_v_callback(const char *value, size_t valuebytes, void *a
 typedef int pmemkv_compare_function(const char *key1, size_t keybytes1, const char *key2,
 				    size_t keybytes2, void *arg);
 
+pmemkv_comparator *pmemkv_comparator_new(pmemkv_compare_function *fn, const char *name,
+					 void *arg);
+void pmemkv_comparator_delete(pmemkv_comparator *comparator);
+
 pmemkv_config *pmemkv_config_new(void);
 void pmemkv_config_delete(pmemkv_config *config);
 int pmemkv_config_put_data(pmemkv_config *config, const char *key, const void *value,
@@ -54,9 +66,11 @@ int pmemkv_config_get_uint64(pmemkv_config *config, const char *key, uint64_t *v
 int pmemkv_config_get_int64(pmemkv_config *config, const char *key, int64_t *value);
 int pmemkv_config_get_string(pmemkv_config *config, const char *key, const char **value);
 
-pmemkv_comparator *pmemkv_comparator_new(pmemkv_compare_function *fn, const char *name,
-					 void *arg);
-void pmemkv_comparator_delete(pmemkv_comparator *comparator);
+int pmemkv_config_put_size(pmemkv_config *config, uint64_t value);
+int pmemkv_config_put_path(pmemkv_config *config, const char *value);
+int pmemkv_config_put_force_create(pmemkv_config *config, bool value);
+int pmemkv_config_put_comparator(pmemkv_config *config, pmemkv_comparator *comparator);
+int pmemkv_config_put_oid(pmemkv_config *config, PMEMoid *oid);
 
 int pmemkv_open(const char *engine, pmemkv_config *config, pmemkv_db **db);
 void pmemkv_close(pmemkv_db *kv);
@@ -95,6 +109,44 @@ int pmemkv_defrag(pmemkv_db *db, double start_percent, double amount_percent);
 
 const char *pmemkv_errormsg(void);
 
+/* This API is EXPERIMENTAL and might change. */
+int pmemkv_tx_begin(pmemkv_db *db, pmemkv_tx **tx);
+int pmemkv_tx_put(pmemkv_tx *tx, const char *k, size_t kb, const char *v, size_t vb);
+int pmemkv_tx_remove(pmemkv_tx *tx, const char *k, size_t kb);
+int pmemkv_tx_commit(pmemkv_tx *tx);
+void pmemkv_tx_abort(pmemkv_tx *tx);
+void pmemkv_tx_end(pmemkv_tx *tx);
+
+/* This API is EXPERIMENTAL and might change. */
+int pmemkv_iterator_new(pmemkv_db *db, pmemkv_iterator **it);
+int pmemkv_write_iterator_new(pmemkv_db *db, pmemkv_write_iterator **it);
+
+void pmemkv_iterator_delete(pmemkv_iterator *it);
+void pmemkv_write_iterator_delete(pmemkv_write_iterator *it);
+
+int pmemkv_iterator_seek(pmemkv_iterator *it, const char *k, size_t kb);
+int pmemkv_iterator_seek_lower(pmemkv_iterator *it, const char *k, size_t kb);
+int pmemkv_iterator_seek_lower_eq(pmemkv_iterator *it, const char *k, size_t kb);
+int pmemkv_iterator_seek_higher(pmemkv_iterator *it, const char *k, size_t kb);
+int pmemkv_iterator_seek_higher_eq(pmemkv_iterator *it, const char *k, size_t kb);
+
+int pmemkv_iterator_seek_to_first(pmemkv_iterator *it);
+int pmemkv_iterator_seek_to_last(pmemkv_iterator *it);
+
+int pmemkv_iterator_is_next(pmemkv_iterator *it);
+int pmemkv_iterator_next(pmemkv_iterator *it);
+int pmemkv_iterator_prev(pmemkv_iterator *it);
+
+int pmemkv_iterator_key(pmemkv_iterator *it, const char **k, size_t *kb);
+
+int pmemkv_iterator_read_range(pmemkv_iterator *it, size_t pos, size_t n,
+			       const char **data, size_t *rb);
+int pmemkv_write_iterator_write_range(pmemkv_write_iterator *it, size_t pos, size_t n,
+				      char **data, size_t *wb);
+
+int pmemkv_write_iterator_commit(pmemkv_write_iterator *it);
+void pmemkv_write_iterator_abort(pmemkv_write_iterator *it);
+
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif
