@@ -3,6 +3,8 @@
 
 #include "unittest.hpp"
 #include <libpmemkv.hpp>
+#include <string>
+#include <vector>
 
 #include <limits>
 
@@ -14,6 +16,8 @@ using namespace pmem::kv;
 
 static const int INIT_VAL = 1;
 static const int DELETED_VAL = 2;
+static const char *PATH = "/some/path";
+static const uint64_t SIZE = 0xDEADBEEF;
 
 struct custom_type {
 	int a;
@@ -29,78 +33,100 @@ static void deleter(custom_type *ct_ptr)
 static void simple_test()
 {
 	/**
-	 * TEST: add and read data from config, using all available methods
+	 * TEST: add and read data from config, using basic methods.
 	 */
 	auto cfg = new config;
 	UT_ASSERT(cfg != nullptr);
 
 	status s = cfg->put_string("string", "abc");
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 
 	s = cfg->put_int64("int", 123);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 
 	custom_type *ptr = new custom_type;
 	ptr->a = INIT_VAL;
 	ptr->b = INIT_VAL;
 	s = cfg->put_object("object_ptr", ptr, nullptr);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 
 	s = cfg->put_data("object", ptr);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 
 	int array[3] = {1, 15, 77};
 	s = cfg->put_data("array", array, 3);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 
 	custom_type *ptr_deleter = new custom_type;
 	ptr_deleter->a = INIT_VAL;
 	ptr_deleter->b = INIT_VAL;
 	s = cfg->put_object("object_ptr_with_deleter", ptr_deleter,
 			    (void (*)(void *)) & deleter);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
+
+	s = cfg->put_path(PATH);
+	ASSERT_STATUS(s, status::OK);
+
+	s = cfg->put_size(SIZE);
+	ASSERT_STATUS(s, status::OK);
+
+	s = cfg->put_force_create(true);
+	ASSERT_STATUS(s, status::OK);
 
 	std::string value_string;
 	s = cfg->get_string("string", value_string);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 	UT_ASSERT(value_string == "abc");
 
 	int64_t value_int;
 	s = cfg->get_int64("int", value_int);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 	UT_ASSERTeq(value_int, 123);
 
 	custom_type *value_custom_ptr;
 	s = cfg->get_object("object_ptr", value_custom_ptr);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 	UT_ASSERTeq(value_custom_ptr->a, INIT_VAL);
 	UT_ASSERTeq(value_custom_ptr->b, INIT_VAL);
 
 	custom_type *value_custom_ptr_deleter;
 	s = cfg->get_object("object_ptr_with_deleter", value_custom_ptr_deleter);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 	UT_ASSERTeq(value_custom_ptr_deleter->a, INIT_VAL);
 	UT_ASSERTeq(value_custom_ptr_deleter->b, INIT_VAL);
 
 	custom_type *value_custom;
-	size_t value_custom_count;
+	size_t value_custom_count = 0;
 	s = cfg->get_data("object", value_custom, value_custom_count);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 	UT_ASSERTeq(value_custom_count, 1U);
 	UT_ASSERTeq(value_custom->a, INIT_VAL);
 	UT_ASSERTeq(value_custom->b, INIT_VAL);
 
 	int *value_array;
-	size_t value_array_count;
+	size_t value_array_count = 0;
 	s = cfg->get_data("array", value_array, value_array_count);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 	UT_ASSERTeq(value_array_count, 3U);
 	UT_ASSERTeq(value_array[0], 1);
 	UT_ASSERTeq(value_array[1], 15);
 	UT_ASSERTeq(value_array[2], 77);
 
 	int64_t none;
-	UT_ASSERTeq(cfg->get_int64("non-existent", none), status::NOT_FOUND);
+	ASSERT_STATUS(cfg->get_int64("non-existent", none), status::NOT_FOUND);
+
+	s = cfg->get_string("path", value_string);
+	ASSERT_STATUS(s, status::OK);
+	UT_ASSERT(value_string == PATH);
+
+	uint64_t int_us;
+	s = cfg->get_uint64("size", int_us);
+	ASSERT_STATUS(s, status::OK);
+	UT_ASSERTeq(int_us, SIZE);
+
+	s = cfg->get_uint64("force_create", int_us);
+	ASSERT_STATUS(s, status::OK);
+	UT_ASSERTeq(int_us, 1);
 
 	delete cfg;
 	cfg = nullptr;
@@ -117,6 +143,70 @@ static void simple_test()
 	delete ptr_deleter;
 }
 
+static void put_edge_cases()
+{
+	/**
+	 * TEST: Edge cases input data for some methods.
+	 */
+
+	auto cfg = new config;
+	auto s = cfg->put_force_create(false);
+	ASSERT_STATUS(s, status::OK);
+
+	uint64_t int_us;
+	s = cfg->get_uint64("force_create", int_us);
+	ASSERT_STATUS(s, status::OK);
+	UT_ASSERTeq(int_us, 0);
+
+	auto max_size = std::numeric_limits<uint64_t>::max();
+	s = cfg->put_size(max_size);
+	ASSERT_STATUS(s, status::OK);
+
+	s = cfg->get_uint64("size", int_us);
+	ASSERT_STATUS(s, status::OK);
+	UT_ASSERTeq(int_us, max_size);
+
+	delete cfg;
+
+	/* Some of those strings are not real paths, but config should not crash on them
+	 * */
+	std::vector<std::string> paths = {" ", "", "//",
+					  ",./;'[]-=<>?:\"{}|_+!@#$%^&*()`~", "/👾"};
+	for (auto path : paths) {
+		auto cfg = new config();
+		s = cfg->put_path(path);
+		ASSERT_STATUS(s, status::OK);
+
+		std::string value_string;
+		s = cfg->get_string("path", value_string);
+		ASSERT_STATUS(s, status::OK);
+		UT_ASSERT(value_string == path);
+		delete cfg;
+	}
+}
+
+static void put_oid_simple_test()
+{
+	/**
+	 * TEST: basic check for put_oid method.
+	 */
+
+	auto cfg = new config;
+	UT_ASSERT(cfg != NULL);
+
+	PMEMoid oid;
+	status ret = cfg->put_oid(&oid);
+	ASSERT_STATUS(ret, status::OK);
+
+	PMEMoid *oid_ptr;
+
+	ret = cfg->get_object("oid", oid_ptr);
+	ASSERT_STATUS(ret, status::OK);
+	UT_ASSERTeq(&oid, oid_ptr);
+
+	delete cfg;
+}
+
 static void object_unique_ptr_default_deleter_test()
 {
 	auto cfg = new config;
@@ -126,7 +216,7 @@ static void object_unique_ptr_default_deleter_test()
 	ptr_default->a = INIT_VAL;
 	ptr_default->b = INIT_VAL;
 	auto s = cfg->put_object("object_ptr", std::move(ptr_default));
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 
 	delete cfg;
 }
@@ -138,11 +228,11 @@ static void object_unique_ptr_nullptr_test()
 
 	auto ptr = std::unique_ptr<custom_type>(nullptr);
 	auto s = cfg->put_object("object_ptr", std::move(ptr));
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 
 	custom_type *raw_ptr;
 	s = cfg->get_object("object_ptr", raw_ptr);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 	UT_ASSERTeq(raw_ptr, nullptr);
 
 	delete cfg;
@@ -166,7 +256,7 @@ static void object_unique_ptr_custom_deleter_test()
 	auto *raw_ptr = ptr_custom.get();
 
 	auto s = cfg->put_object("object_ptr", std::move(ptr_custom));
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 
 	delete cfg;
 
@@ -187,53 +277,53 @@ static void integral_conversion_test()
 	UT_ASSERT(cfg != nullptr);
 
 	status s = cfg->put_int64("int", 123);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 
 	s = cfg->put_uint64("uint", 123);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 
 	s = cfg->put_int64("negative-int", -123);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 
 	s = cfg->put_uint64("uint-max", std::numeric_limits<size_t>::max());
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 
 	int64_t int_s;
 	s = cfg->get_int64("int", int_s);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 	UT_ASSERTeq(int_s, 123);
 
 	size_t int_us;
 	s = cfg->get_uint64("int", int_us);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 	UT_ASSERTeq(int_us, 123U);
 
 	int64_t uint_s;
 	s = cfg->get_int64("uint", uint_s);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 	UT_ASSERTeq(uint_s, 123);
 
 	size_t uint_us;
 	s = cfg->get_uint64("uint", uint_us);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 	UT_ASSERTeq(uint_us, 123U);
 
 	int64_t neg_int_s;
 	s = cfg->get_int64("negative-int", neg_int_s);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 	UT_ASSERTeq(neg_int_s, -123);
 
 	size_t neg_int_us;
 	s = cfg->get_uint64("negative-int", neg_int_us);
-	UT_ASSERTeq(s, status::CONFIG_TYPE_ERROR);
+	ASSERT_STATUS(s, status::CONFIG_TYPE_ERROR);
 
 	int64_t uint_max_s;
 	s = cfg->get_int64("uint-max", uint_max_s);
-	UT_ASSERTeq(s, status::CONFIG_TYPE_ERROR);
+	ASSERT_STATUS(s, status::CONFIG_TYPE_ERROR);
 
 	size_t uint_max_us;
 	s = cfg->get_uint64("uint-max", uint_max_us);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 	UT_ASSERTeq(uint_max_us, std::numeric_limits<size_t>::max());
 
 	delete cfg;
@@ -254,13 +344,13 @@ static void constructors_test()
 
 	/* put value to C++ config */
 	auto s = cfg->put_int64("int", 65535);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 
 	/* use move constructor and test if data is still accessible */
 	config *move_config = new config(std::move(*cfg));
 	int64_t int_s;
 	s = move_config->get_int64("int", int_s);
-	UT_ASSERTeq(s, status::OK);
+	ASSERT_STATUS(s, status::OK);
 	UT_ASSERTeq(int_s, 65535);
 
 	/* release new C++ config and test if data is accessible in C config */
@@ -271,12 +361,35 @@ static void constructors_test()
 
 	/* check if moved config is empty */
 	s = move_config->get_int64("int", int_s);
-	UT_ASSERTeq(s, status::NOT_FOUND);
+	ASSERT_STATUS(s, status::NOT_FOUND);
+
+	/* create new config... */
+	delete cfg;
+	cfg = new config();
+	s = cfg->put_string("string", "config");
+	ASSERT_STATUS(s, status::OK);
+
+	config *move_assign = new config();
+	s = move_assign->put_string("move_string", "value");
+	ASSERT_STATUS(s, status::OK);
+
+	/* ... and check move assignment operator
+		from different and the same config */
+	*move_assign = std::move(*cfg);
+	auto &move_assign2 = *move_assign;
+	*move_assign = std::move(move_assign2);
+
+	std::string string_s;
+	s = move_assign->get_string("move_string", string_s);
+	ASSERT_STATUS(s, status::NOT_FOUND);
+	s = move_assign->get_string("string", string_s);
+	ASSERT_STATUS(s, status::OK);
+	UT_ASSERT(string_s == "config");
 
 	/* cleanup */
 	pmemkv_config_delete(c_cfg);
 	delete move_config;
-
+	delete move_assign;
 	delete cfg;
 }
 
@@ -296,24 +409,26 @@ static void not_found_test()
 	custom_type *my_object;
 	size_t my_object_count = 0;
 
-	UT_ASSERTeq(cfg->get_string("string", my_string), status::NOT_FOUND);
-	UT_ASSERTeq(cfg->get_int64("int", my_int), status::NOT_FOUND);
-	UT_ASSERTeq(cfg->get_uint64("uint", my_uint), status::NOT_FOUND);
-	UT_ASSERTeq(cfg->get_object("object", my_object), status::NOT_FOUND);
-	UT_ASSERTeq(cfg->get_data("data", my_object, my_object_count), status::NOT_FOUND);
+	ASSERT_STATUS(cfg->get_string("string", my_string), status::NOT_FOUND);
+	ASSERT_STATUS(cfg->get_int64("int", my_int), status::NOT_FOUND);
+	ASSERT_STATUS(cfg->get_uint64("uint", my_uint), status::NOT_FOUND);
+	ASSERT_STATUS(cfg->get_object("object", my_object), status::NOT_FOUND);
+	ASSERT_STATUS(cfg->get_data("data", my_object, my_object_count),
+		      status::NOT_FOUND);
 	UT_ASSERTeq(my_object_count, 0U);
 
 	/* initialize config with any put */
 	cfg->put_int64("init", 0);
 
 	/* all gets should return NOT_FOUND when looking for non-existing key */
-	UT_ASSERTeq(cfg->get_string("non-existent-string", my_string), status::NOT_FOUND);
-	UT_ASSERTeq(cfg->get_int64("non-existent-int", my_int), status::NOT_FOUND);
-	UT_ASSERTeq(cfg->get_uint64("non-existent-uint", my_uint), status::NOT_FOUND);
-	UT_ASSERTeq(cfg->get_object("non-existent-object_ptr", my_object),
-		    status::NOT_FOUND);
-	UT_ASSERTeq(cfg->get_data("non-existent-data", my_object, my_object_count),
-		    status::NOT_FOUND);
+	ASSERT_STATUS(cfg->get_string("non-existent-string", my_string),
+		      status::NOT_FOUND);
+	ASSERT_STATUS(cfg->get_int64("non-existent-int", my_int), status::NOT_FOUND);
+	ASSERT_STATUS(cfg->get_uint64("non-existent-uint", my_uint), status::NOT_FOUND);
+	ASSERT_STATUS(cfg->get_object("non-existent-object_ptr", my_object),
+		      status::NOT_FOUND);
+	ASSERT_STATUS(cfg->get_data("non-existent-data", my_object, my_object_count),
+		      status::NOT_FOUND);
 	UT_ASSERTeq(my_object_count, 0U);
 
 	delete cfg;
@@ -324,6 +439,8 @@ static void not_found_test()
 static void test(int argc, char *argv[])
 {
 	simple_test();
+	put_oid_simple_test();
+	put_edge_cases();
 	object_unique_ptr_nullptr_test();
 	object_unique_ptr_default_deleter_test();
 	object_unique_ptr_custom_deleter_test();
