@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: BSD-3-Clause
 /* Copyright 2020, Intel Corporation */
 
-#include "../all/put_get_std_map.hpp"
+#include "../put_get_std_map.hpp"
 
 #include <libpmemobj++/persistent_ptr.hpp>
 #include <libpmemobj++/pool.hpp>
@@ -25,17 +25,22 @@ static void test(int argc, char *argv[])
 	auto pmemobj_pool_path = std::string(argv[2]);
 	pmem::obj::pool<Root> pmemobj_pool;
 
+	auto layout = std::string("pmemkv");
+	auto engine = std::string(argv[1]);
+	if (engine != "cmap")
+		layout = "pmemkv_" + engine;
+
 	try {
-		pmemobj_pool = pmem::obj::pool<Root>::open(pmemobj_pool_path, "pmemkv");
+		pmemobj_pool = pmem::obj::pool<Root>::open(pmemobj_pool_path, layout);
 	} catch (std::exception &e) {
 		UT_FATALexc(e);
 	}
 
 	pmem::kv::config cfg;
-	auto s = cfg.put_object("oid", &pmemobj_pool.root()->oid, nullptr);
-	UT_ASSERTeq(s, status::OK);
+	auto s = cfg.put_oid(&pmemobj_pool.root()->oid);
+	ASSERT_STATUS(s, status::OK);
 
-	auto kv = INITIALIZE_KV(argv[1], std::move(cfg));
+	auto kv = INITIALIZE_KV(engine, std::move(cfg));
 
 	auto proto = PutToMapTest(n_inserts, key_length, value_length, kv);
 	VerifyKv(proto, kv);
