@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2019-2020, Intel Corporation */
+/* Copyright 2019-2021, Intel Corporation */
 
 #include <libpmemkv.hpp>
 
@@ -25,19 +25,22 @@ static void errormsg_test()
 	 */
 	pmem::kv::db kv;
 	auto s = kv.open("non-existing name");
-	UT_ASSERT(s == pmem::kv::status::WRONG_ENGINE_NAME);
+	ASSERT_STATUS(s, pmem::kv::status::WRONG_ENGINE_NAME);
 
 	auto err = pmem::kv::errormsg();
 	UT_ASSERT(err.size() > 0);
 
 	s = kv.open("non-existing name");
-	UT_ASSERT(s == pmem::kv::status::WRONG_ENGINE_NAME);
+	ASSERT_STATUS(s, pmem::kv::status::WRONG_ENGINE_NAME);
 	s = kv.open("non-existing name");
-	UT_ASSERT(s == pmem::kv::status::WRONG_ENGINE_NAME);
+	ASSERT_STATUS(s, pmem::kv::status::WRONG_ENGINE_NAME);
 
 	/* Test whether errormsg is cleared correctly after each error */
 	UT_ASSERT(pmem::kv::errormsg() == err);
 
+	/* Test if instance of db reports the same error */
+	UT_ASSERT(kv.errormsg() == err);
+
 	kv.close();
 }
 
@@ -69,8 +72,12 @@ int main()
 	UT_ASSERT(wrong_engine_name_test("stree"));
 #endif
 
-#ifndef ENGINE_CACHING
-	UT_ASSERT(wrong_engine_name_test("caching"));
+#ifndef ENGINE_RADIX
+	UT_ASSERT(wrong_engine_name_test("radix"));
+#endif
+
+#ifndef ENGINE_ROBINHOOD
+	UT_ASSERT(wrong_engine_name_test("robinhood"));
 #endif
 
 	errormsg_test();
