@@ -10,17 +10,14 @@ set -e
 
 source `dirname $0`/prepare-for-build.sh
 
-# master: Merge pull request #44 from lukaszstolarczuk/update-tra..., 21.11.2019
+# master: Merge pull request #44 from lukaszstolarczuk/update-tr..., 21.11.2019
 RUBY_VERSION="3741e3df698245fc8a15822a1aa85b5c211fd332"
 
-# master: Merge pull request #34 from igchor/add_pmemkv_errormsg, 06.12.2020
-JNI_VERSION="fcc8370b230ab3236d062a121e22dcebf37b90ec"
+# master: Merge pull request #90 from lukaszstolarczuk/merge-sta..., 09.09.2020
+JAVA_VERSION="e04ca43b5e5590c653cbdec35a87e0279a4f1a7a"
 
-# master: Merge pull request #38 from lukaszstolarczuk/update-tra..., 17.03.2020
-JAVA_VERSION="ab8747c3baf4af8cd2ce1985986d7fcc241ccd65"
-
-# master: Merge pull request #49 from how759/buffer-arguments, 02.03.2020
-NODEJS_VERSION="12ecc0a9c3205425bf0aa1767eada53834535045"
+# master: Merge pull request #55 from lukaszstolarczuk/fix-comment, 03.04.2020
+NODEJS_VERSION="76600e002b9d9105d3f46b7cc2bf991931286cec"
 
 # master: ver. 1.0, 03.03.2020
 PYTHON_VERSION="094bc84fdabff81c2eb2017d32caad2582835f90"
@@ -39,7 +36,7 @@ echo
 echo "##################################################################"
 echo "### Verifying building and installing of the pmemkv-ruby bindings "
 echo "##################################################################"
-cd ~
+cd $WORKDIR
 git clone https://github.com/pmem/pmemkv-ruby.git
 cd pmemkv-ruby
 git checkout $RUBY_VERSION
@@ -48,35 +45,29 @@ cp -r /opt/bindings/ruby/* vendor/cache/
 bundle install --local
 bundle exec rspec
 
-echo
-echo "#################################################################"
-echo "### Verifying building and installing of the pmemkv-jni bindings "
-echo "#################################################################"
-cd ~
-git clone https://github.com/pmem/pmemkv-jni.git
-cd pmemkv-jni
-git checkout $JNI_VERSION
-
-make test
-sudo_password -S make install prefix=$PREFIX
+cd ..
+rm -rf pmemkv-ruby
 
 echo
 echo "##################################################################"
 echo "### Verifying building and installing of the pmemkv-java bindings "
 echo "##################################################################"
-cd ~
+cd $WORKDIR
 git clone https://github.com/pmem/pmemkv-java.git
 cd pmemkv-java
 git checkout $JAVA_VERSION
 mkdir -p ~/.m2/repository
 cp -r /opt/bindings/java/repository ~/.m2/
-mvn --offline install
+mvn install
+
+cd ..
+rm -rf pmemkv-java
 
 echo
 echo "####################################################################"
 echo "### Verifying building and installing of the pmemkv-nodejs bindings "
 echo "####################################################################"
-cd ~
+cd $WORKDIR
 git clone https://github.com/pmem/pmemkv-nodejs.git
 cd pmemkv-nodejs
 git checkout $NODEJS_VERSION
@@ -84,11 +75,14 @@ cp -r /opt/bindings/nodejs/node_modules .
 npm install --save
 npm test
 
+cd ..
+rm -rf pmemkv-nodejs
+
 echo
 echo "####################################################################"
 echo "### Verifying building and installing of the pmemkv-python bindings "
 echo "####################################################################"
-cd ~
+cd $WORKDIR
 git clone https://github.com/pmem/pmemkv-python.git
 cd pmemkv-python
 git checkout $PYTHON_VERSION
@@ -98,3 +92,6 @@ cd tests
 python3 -m unittest -v pmemkv_tests.py
 cd ../examples
 PMEM_IS_PMEM_FORCE=1 python3 basic_example.py
+
+cd ../..
+rm -rf pmemkv-python
