@@ -1,27 +1,30 @@
 #!/usr/bin/env bash
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright 2019-2020, Intel Corporation
+# Copyright 2019-2021, Intel Corporation
 
 #
 # run-test-building.sh - is called inside a Docker container,
 #                        starts testing of pmemkv building
-#                        and automatic update of the documentation
+#                        and automatic update of the documentation.
 #
 
 set -e
 
 source `dirname $0`/prepare-for-build.sh
 
+# params set for the file (if not previously set, the right-hand param is used)
 TEST_DIR=${PMEMKV_TEST_DIR:-${DEFAULT_TEST_DIR}}
 TEST_PACKAGES=${TEST_PACKAGES:-ON}
 BUILD_JSON_CONFIG=${BUILD_JSON_CONFIG:-ON}
+TESTS_USE_FORCED_PMEM=${TESTS_USE_FORCED_PMEM:-ON}
+TEST_TIMEOUT=${TEST_TIMEOUT:-600}
 
-function run_test_check_support_cpp20_gcc() {
+###############################################################################
+# BUILD test_gcc_cpp20
+###############################################################################
+function test_gcc_cpp20() {
+	printf "\n$(tput setaf 1)$(tput setab 7)BUILD ${FUNCNAME[0]} START$(tput sgr 0)\n"
 	CWD=$(pwd)
-	echo
-	echo "##############################################################"
-	echo "### Checking C++20 support in g++"
-	echo "##############################################################"
 	mkdir $WORKDIR/build
 	cd $WORKDIR/build
 
@@ -31,46 +34,27 @@ function run_test_check_support_cpp20_gcc() {
 		-DBUILD_JSON_CONFIG=${BUILD_JSON_CONFIG} \
 		-DCOVERAGE=$COVERAGE \
 		-DDEVELOPER_MODE=1 \
+		-DTESTS_USE_FORCED_PMEM=${TESTS_USE_FORCED_PMEM} \
 		-DCXX_STANDARD=20
 
 	make -j$(nproc)
 	# Run basic tests
-	ctest -R "SimpleTest" --output-on-failure
+	ctest -R "SimpleTest" --output-on-failure --timeout ${TEST_TIMEOUT}
 
-	cd $CWD
-	rm -rf $WORKDIR/build
+	if [ "$COVERAGE" == "1" ]; then
+		upload_codecov test_gcc_cpp20
+	fi
+
+	workspace_cleanup
+
+	printf "$(tput setaf 1)$(tput setab 7)BUILD ${FUNCNAME[0]} END$(tput sgr 0)\n\n"
 }
 
-function run_test_check_support_cpp20_clang() {
-	CWD=$(pwd)
-	echo
-	echo "##############################################################"
-	echo "### Checking C++20 support in clang++"
-	echo "##############################################################"
-	mkdir $WORKDIR/build
-	cd $WORKDIR/build
-
-	CC=clang CXX=clang++ cmake .. -DCMAKE_BUILD_TYPE=Release \
-		-DTEST_DIR=$TEST_DIR \
-		-DCMAKE_INSTALL_PREFIX=$PREFIX \
-		-DBUILD_JSON_CONFIG=${BUILD_JSON_CONFIG} \
-		-DCOVERAGE=$COVERAGE \
-		-DDEVELOPER_MODE=1 \
-		-DCXX_STANDARD=20
-
-	make -j$(nproc)
-	# Run basic tests
-	ctest -R "SimpleTest" --output-on-failure
-
-	cd $CWD
-	rm -rf $WORKDIR/build
-}
-
-function verify_building_of_packages() {
-	echo
-	echo "##############################################################"
-	echo "### Verifying building of packages"
-	echo "##############################################################"
+###############################################################################
+# BUILD test_building_of_packages
+###############################################################################
+function test_building_of_packages() {
+	printf "\n$(tput setaf 1)$(tput setab 7)BUILD ${FUNCNAME[0]} START$(tput sgr 0)\n"
 
 	# Fetch git history for `git describe` to work,
 	# so that package has proper 'version' field
@@ -113,16 +97,21 @@ function verify_building_of_packages() {
 		sudo_password rpm -e --nodeps libpmemkv-devel
 	fi
 
-	cd $WORKDIR
-	rm -rf $WORKDIR/build
+	workspace_cleanup
+
+	printf "$(tput setaf 1)$(tput setab 7)BUILD ${FUNCNAME[0]} END$(tput sgr 0)\n\n"
 }
 
+# helper function to check building with specified CMake flag
 function build_with_flags() {
+	printf "\n$(tput setaf 1)$(tput setab 7)BUILD ${FUNCNAME[0]} START$(tput sgr 0)\n"
+
 	CMAKE_FLAGS_AND_SETTINGS=$@
 	echo
 	echo "##############################################################"
 	echo "### Verifying building with flag: ${CMAKE_FLAGS_AND_SETTINGS}"
 	echo "##############################################################"
+
 	mkdir $WORKDIR/build
 	cd $WORKDIR/build
 
@@ -131,21 +120,19 @@ function build_with_flags() {
 	# list all tests in this build
 	ctest -N
 
-	cd $WORKDIR
-	rm -rf $WORKDIR/build
+	workspace_cleanup
+
+	printf "$(tput setaf 1)$(tput setab 7)BUILD ${FUNCNAME[0]} END$(tput sgr 0)\n\n"
 }
 
-cd $WORKDIR
+# Main:
 
-CMAKE_VERSION=$(cmake --version | head -n1 | grep -oE '[0-9].[0-9]*')
-CMAKE_VERSION_MAJOR=$(echo $CMAKE_VERSION | cut -d. -f1)
-CMAKE_VERSION_MINOR=$(echo $CMAKE_VERSION | cut -d. -f2)
-CMAKE_VERSION_NUMBER=$((100 * $CMAKE_VERSION_MAJOR + $CMAKE_VERSION_MINOR))
+workspace_cleanup
+cd $WORKDIR
 
 # CXX_STANDARD==20 is supported since CMake 3.12
 if [ $CMAKE_VERSION_NUMBER -ge 312 ]; then
-	run_test_check_support_cpp20_gcc
-	run_test_check_support_cpp20_clang
+	test_gcc_cpp20
 fi
 
 echo
@@ -157,11 +144,10 @@ engines_flags=(
 	ENGINE_VCMAP
 	ENGINE_CMAP
 	ENGINE_CSMAP
-	# XXX: caching engine requires libacl and memcached installed in docker images
-	# and firstly we need to remove hardcoded INCLUDE paths (see #244)
-	# ENGINE_CACHING
 	ENGINE_STREE
 	ENGINE_TREE3
+	ENGINE_RADIX
+	ENGINE_ROBINHOOD
 	# the last item is to test all engines disabled
 	BLACKHOLE_TEST
 )
@@ -185,14 +171,9 @@ do
 	make -j$(nproc)
 	# list all tests in this build
 	ctest -N
-	ctest -R wrong_engine_name_test --output-on-failure
+	ctest -R wrong_engine_name_test --output-on-failure --timeout ${TEST_TIMEOUT}
 
-	if [ "$COVERAGE" == "1" ]; then
-		upload_codecov tests
-	fi
-
-	cd $WORKDIR
-	rm -rf $WORKDIR/build
+	workspace_cleanup
 done
 
 echo
@@ -209,36 +190,27 @@ cmake .. -DCXX_STANDARD=14 \
 	-DENGINE_CSMAP=ON \
 	-DENGINE_STREE=ON \
 	-DENGINE_TREE3=ON \
+	-DENGINE_RADIX=ON \
+	-DENGINE_ROBINHOOD=ON \
 	-DBUILD_JSON_CONFIG=${BUILD_JSON_CONFIG}
 make -j$(nproc)
 # list all tests in this build
 ctest -N
 
-cd $WORKDIR
-rm -rf $WORKDIR/build
+workspace_cleanup
 
-# test build with specific CMake flags set
+echo
+echo "##############################################################"
+echo "### Verifying build with specific CMake flags"
+echo "##############################################################"
 build_with_flags -DBUILD_JSON_CONFIG=OFF -DTESTS_JSON=OFF
 
 # building of packages should be verified only if PACKAGE_MANAGER equals 'rpm' or 'deb'
 case $PACKAGE_MANAGER in
 	rpm|deb)
-		[ "$TEST_PACKAGES" == "ON" ] && verify_building_of_packages
+		[ "$TEST_PACKAGES" == "ON" ] && test_building_of_packages
 		;;
 	*)
 		echo "Notice: skipping building of packages because PACKAGE_MANAGER is not equal 'rpm' nor 'deb' ..."
 		;;
 esac
-
-# Trigger auto doc update on master
-if [[ "$AUTO_DOC_UPDATE" == "1" ]]; then
-	echo "Running auto doc update"
-
-	mkdir -p $WORKDIR/doc_update
-	cd $WORKDIR/doc_update
-
-	$SCRIPTSDIR/run-doc-update.sh
-
-	cd $WORKDIR
-	rm -rf $WORKDIR/doc_update
-fi
